@@ -38,8 +38,9 @@
 (declare-function detached-copy-session-command "detached")
 (declare-function detached-copy-session "detached")
 (declare-function detached-diff-session "detached")
-
+(declare-function detached-initialize-sessions "detached")
 (declare-function detached-shell-mode "detached")
+
 (declare-function detached-compile--start "detached-compile")
 (declare-function detached-dired-do-shell-command "detached-dired")
 (declare-function detached-eshell-mode "detached-eshell")
@@ -105,10 +106,7 @@
 ;;;###autoload
 (defun detached-init ()
   "Initialize `detached' integration with all packages."
-
-  ;; Required for `detached-shell-command' which is always provided
-  (add-hook 'shell-mode-hook #'detached-shell-mode)
-
+  (detached-init--detached)
   (let ((init-functions
          (thread-last detached-init--package-integration
                       (seq-filter (lambda (it)
@@ -166,6 +164,14 @@
     (defvar embark-detached-map (make-composed-keymap detached-action-map embark-general-map))
     (add-to-list 'embark-keymap-alist '(detached . embark-detached-map))))
 
+(defun detached-init--detached ()
+  "Initialize `detached'."
+  ;; Trigger initialization of sessions upon load of `detached'
+  (with-eval-after-load 'detached
+    (detached-initialize-sessions))
+  ;; Required for `detached-shell-command' which is always provided
+  (add-hook 'shell-mode-hook #'detached-shell-mode))
+
 (provide 'detached-init)
 
 ;;; detached-init.el ends here
